#!/usr/bin/python

import glob
import os.path
import re

from datetime import datetime


DEMO_DIR = "/home/ant/.xonotic/data/demos"
SS_DIR = "/home/ant/.xonotic/data/screenshots/topfrags"


class Demo:
    def __init__(self, filename):
        demo_re = r"(\d{4})-(\d{2})-(\d{2})_(\d{2})-(\d{2})_(.*).dem"
        m = re.match(demo_re, filename)
        if m is not None:
            year           = m.group(1)
            month          = m.group(2)
            day            = m.group(3)
            hour           = m.group(4)
            minute         = m.group(5)
            map_name       = m.group(6)

            self.filename  = filename
            self.date_time = datetime(int(year), int(month), int(day),
                    int(hour), int(minute))
            self.map_name  = map_name
            self.key       = year + month + day
        else:
            self.date_time = None
            self.map_name  = None
            self.key       = None

class Screenshot:
    def __init__(self, filename):
        ss_re = r"(\w*)-(\d{1,3}).\d*-(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})"
        m = re.match(ss_re, filename)
        if m is not None:
            map_name    = m.group(1)
            frag_second = m.group(2)
            year        = m.group(3)
            month       = m.group(4)
            day         = m.group(5)
            hour        = m.group(6)
            minute      = m.group(7)
            second      = m.group(8)

            self.filename  = filename
            self.frag_second = int(frag_second)
            self.date_time = datetime(int(year), int(month), int(day),
                    int(hour), int(minute), int(second))
            self.map_name = map_name
            self.key    = year + month + day

# first let's grab the demos and sort them by time
demo_filenames = map(os.path.basename, glob.glob(DEMO_DIR + "/*dem"))
demos = []
for demo_filename in demo_filenames:
    demos.append(Demo(demo_filename))
demos = sorted(demos, key=lambda d: d.date_time)

# now let's index them by date
demos_by_date = {}
for d in demos:
    key = d.key
    if key in demos_by_date:
        demos_by_date[key].append(d)
    else:
        demos_by_date[key] = [d]

# now we do the same for screenshots
screenshot_filenames = map(os.path.basename, glob.glob(SS_DIR + "/*jpg"))
screenshots = []
for screenshot_filename in screenshot_filenames:
    screenshots.append(Screenshot(screenshot_filename))

# now let's match the screenshots to the demos!
for s in screenshots:
    potential_demos = filter(lambda d: d.map_name == s.map_name, demos_by_date[s.key])

    demo = None
    for d in potential_demos:
        if d.date_time > s.date_time:
            break
        else:
            demo = d

    print("Screenshot: {}\nDemo: {}\nEnd time: {}\n".\
            format(s.filename, demo.filename, s.frag_second))
